@@ -71,15 +71,17 @@ def _assert_pmapped(fn, fn_input, is_pmapped, should_jit=False):
   # We test whether the function has been pmapped by inspecting the type of
   # the function output, if it is a sharded array type then the function has
   # been pmapped
-  if not is_pmapped and hasattr(jax.interpreters.xla, 'type_is_device_array'):
+  if is_pmapped:
+    expected_type = ArraySharded
+    assert_message = f'Output is type {type(output)}, expected {expected_type}'
+    assert isinstance(output, expected_type), assert_message
+  else:
     expected_type = 'DeviceArray'
     assert_message = f'Output is type {type(output)}, expected {expected_type}'
-    assert jax.interpreters.xla.type_is_device_array(output), assert_message
-  else:
-    expected_type = ArraySharded if is_pmapped else jnp.DeviceArray
-    assert_message = f'Output is type {type(output)}, expected {expected_type}'
-    # We want to check exact types here
-    assert type(output) == expected_type, assert_message    # pylint: disable=unidiomatic-typecheck
+    # ShardedDeviceArray is a subclass of DeviceArray. So, to enforce we have
+    # a DeviceArray, we also check it's not a sharded one.
+    assert (isinstance(output, jnp.DeviceArray) and
+            not isinstance(output, ArraySharded)), assert_message
 
 
 class PmapFakeTest(parameterized.TestCase):
@@ -147,8 +149,9 @@ class PmapFakeTest(parameterized.TestCase):
   def test_fake_pmap_axis_name(self):
 
     with fake.fake_pmap():
-      @jax.partial(jax.pmap, axis_name='i')
-      @jax.partial(jax.pmap, axis_name='j')
+
+      @functools.partial(jax.pmap, axis_name='i')
+      @functools.partial(jax.pmap, axis_name='j')
       def f(_):
         return jax.lax.axis_index('i'), jax.lax.axis_index('j')
       x, y = f(jnp.zeros((4, 2)))
@@ -309,6 +312,87 @@ class PmapFakeTest(parameterized.TestCase):
       asserts.assert_trees_all_close(
           overidden_foo(x=inputs, y=inputs), expected)
 
+  def test_parallel_ops_equivalence(self):
+    """Test equivalence between parallel operations using pmap and vmap."""
+    num_devices = len(jax.devices())
+    inputs = jax.random.uniform(shape=(num_devices, num_devices, 2),
+                                key=jax.random.PRNGKey(1))
+
+    def test_equivalence(fn):
+      with fake.fake_pmap(enable_patching=False):
+        outputs1 = jax.pmap(fn, axis_name='i', axis_size=num_devices)(inputs)
+      with fake.fake_pmap(enable_patching=True):
+        outputs2 = jax.pmap(fn, axis_name='i', axis_size=num_devices)(inputs)
+      with fake.fake_pmap(enable_patching=True, jit_result=True):
+        outputs3 = jax.pmap(fn, axis_name='i', axis_size=num_devices)(inputs)
+      asserts.assert_trees_all_close(outputs1, outputs2, outputs3)
+
+    parallel_ops_and_kwargs = [
+        (jax.lax.psum, {}),
+        (jax.lax.pmax, {}),
+        (jax.lax.pmin, {}),
+        (jax.lax.pmean, {}),
+        (jax.lax.all_gather, {}),
+        (jax.lax.all_to_all, {
+            'split_axis': 0,
+            'concat_axis': 1
+        }),
+        (jax.lax.ppermute, {
+            'perm': [(x, (x + 1) % num_devices) for x in range(num_devices)]
+        }),
+    ]
+
+    def fn(op, kwargs, x, y=2.0):
+      return op(x * y, axis_name='i', **kwargs)
+    partial_fn = functools.partial(fn, y=4.0)
+    lambda_fn = lambda op, kwargs, x: fn(op, kwargs, x, y=5.0)
+
+    for op, kwargs in parallel_ops_and_kwargs:
+      test_equivalence(functools.partial(fn, op, kwargs))
+      test_equivalence(functools.partial(fn, op, kwargs, y=3.0))
+      test_equivalence(functools.partial(partial_fn, op, kwargs))
+      test_equivalence(functools.partial(lambda_fn, op, kwargs))
+
+  def test_fake_parallel_axis(self):
+    inputs = jnp.ones(shape=(2, 2))
+    with fake.fake_pmap(fake_parallel_axis=False):
+      @jax.pmap
+      def no_fake_parallel_axis_fn(x):
+        asserts.assert_shape(x, (2,))
+        return 2.0 * x
+
+      outputs = no_fake_parallel_axis_fn(inputs)
+      asserts.assert_trees_all_close(outputs, 2.0)
+
+    with fake.fake_pmap(fake_parallel_axis=True):
+      @jax.pmap
+      def fake_parallel_axis_fn(x):
+        asserts.assert_shape(x, (2, 2,))
+        return 2.0 * x
+
+      outputs = fake_parallel_axis_fn(inputs)
+      asserts.assert_trees_all_close(outputs, 2.0)
+
+
+class _Counter():
+  """Counts how often an instance is called."""
+
+  def __init__(self):
+    self.count = 0
+
+  def __call__(self, *unused_args, **unused_kwargs):
+    self.count += 1
+
+
+class OnCallOfTransformedFunctionTest(parameterized.TestCase):
+
+  def test_on_call_of_transformed_function(self):
+    counter = _Counter()
+    with fake.OnCallOfTransformedFunction('jax.jit', counter):
+      jax.jit(jnp.sum)(jnp.zeros((10,)))
+      jax.jit(jnp.max)(jnp.zeros((10,)))
+    self.assertEqual(counter.count, 2)
+
 
 if __name__ == '__main__':
   absltest.main()
