@@ -596,26 +596,59 @@ class WithJitTest(parameterized.TestCase):
   @variants.variants(with_jit=True)
   @parameterized.parameters(*DEFAULT_PARAMS)
   def test_different_jit_kwargs(self, arg_0, arg_1, expected):
+    kwarg_0 = arg_0
+    kwarg_1 = arg_1
 
     arg_0_type = type(arg_0)
     arg_1_type = type(arg_1)
+    kwarg_0_type = type(kwarg_0)
+    kwarg_1_type = type(kwarg_1)
 
-    @self.variant(static_argnums=(0,))
-    def fn_0(arg_0, arg_1):
+    @self.variant(static_argnums=(0,), static_argnames=('kwarg_1',))
+    def fn_0(arg_0, arg_1, kwarg_0, kwarg_1):
+      self.assertIsInstance(arg_0, arg_0_type)
+      self.assertNotIsInstance(arg_1, arg_1_type)
+      self.assertNotIsInstance(kwarg_0, kwarg_0_type)
+      self.assertIsInstance(kwarg_1, kwarg_1_type)
+      return DEFAULT_FN(arg_0 + kwarg_0, arg_1 + kwarg_1)
+
+    actual_0 = fn_0(arg_0, arg_1, kwarg_0=kwarg_0, kwarg_1=kwarg_1)
+    self.assertEqual(actual_0, 2 * expected)
+
+    @self.variant(static_argnums=(1, 3), static_argnames=('kwarg_1',))
+    def fn_1(arg_0, arg_1, kwarg_0, kwarg_1):
+      self.assertNotIsInstance(arg_0, arg_0_type)
+      self.assertIsInstance(arg_1, arg_1_type)
+      self.assertNotIsInstance(kwarg_0, kwarg_0_type)
+      self.assertIsInstance(kwarg_1, kwarg_1_type)
+      return DEFAULT_FN(arg_0 + kwarg_0, arg_1 + kwarg_1)
+
+    actual_1 = fn_1(arg_0, arg_1, kwarg_0=kwarg_0, kwarg_1=kwarg_1)
+    self.assertEqual(actual_1, 2 * expected)
+
+    @self.variant(static_argnums=(), static_argnames=('kwarg_0',))
+    def fn_2(arg_0, arg_1, kwarg_0, kwarg_1):
+      self.assertNotIsInstance(arg_0, arg_0_type)
+      self.assertNotIsInstance(arg_1, arg_1_type)
+      self.assertIsInstance(kwarg_0, kwarg_0_type)
+      self.assertNotIsInstance(kwarg_1, kwarg_1_type)
+      return DEFAULT_FN(arg_0 + kwarg_0, arg_1 + kwarg_1)
+
+    actual_2 = fn_2(arg_0, arg_1, kwarg_0=kwarg_0, kwarg_1=kwarg_1)
+    self.assertEqual(actual_2, 2 * expected)
+
+    def fn_3(arg_0, arg_1):
       self.assertIsInstance(arg_0, arg_0_type)
       self.assertNotIsInstance(arg_1, arg_1_type)
       return DEFAULT_FN(arg_0, arg_1)
 
-    @self.variant(static_argnums=(1,))
-    def fn_1(arg_0, arg_1):
-      self.assertNotIsInstance(arg_0, arg_0_type)
-      self.assertIsInstance(arg_1, arg_1_type)
-      return DEFAULT_FN(arg_0, arg_1)
-
-    actual_0 = fn_0(arg_0, arg_1)
-    actual_1 = fn_1(arg_0, arg_1)
-    self.assertEqual(actual_0, expected)
-    self.assertEqual(actual_1, expected)
+    fn_3_v0 = self.variant(static_argnums=0, static_argnames='arg_0')(fn_3)
+    fn_3_v1 = self.variant(static_argnums=0)(fn_3)
+    fn_3_v2 = self.variant(static_argnums=(), static_argnames='arg_0')(fn_3)
+    self.assertEqual(fn_3_v0(arg_0, arg_1), expected)
+    self.assertEqual(fn_3_v1(arg_0=arg_0, arg_1=arg_1), expected)
+    self.assertEqual(fn_3_v1(arg_0, arg_1=arg_1), expected)
+    self.assertEqual(fn_3_v2(arg_0=arg_0, arg_1=arg_1), expected)
 
 
 def _test_fn_without_device(arg_0, arg_1):
@@ -701,8 +734,8 @@ class WithPmapAllAvailableDeviceTest(parameterized.TestCase):
     super().setUp()
 
     # Choose devices and a backend.
-    n_tpu = asserts._num_devices_available('tpu')
-    n_gpu = asserts._num_devices_available('gpu')
+    n_tpu = asserts._ai.num_devices_available('tpu')
+    n_gpu = asserts._ai.num_devices_available('gpu')
     if n_tpu > 1:
       self.n_devices, self.backend = n_tpu, 'tpu'
     elif n_gpu > 1:
@@ -788,9 +821,8 @@ class WithPmapAllAvailableDeviceTest(parameterized.TestCase):
 
     actual_shape = (n_copies,)
     varg_0 = _scalar_to_ndarray(arg_0, actual_shape)
-    varg_1 = _scalar_to_ndarray(arg_1, actual_shape)
     arg_0_type = type(varg_0)
-    arg_1_type = type(varg_1)
+    arg_1_type = type(arg_1)
 
     @self.variant(
         reduce_fn=None,
@@ -803,6 +835,7 @@ class WithPmapAllAvailableDeviceTest(parameterized.TestCase):
       self.assertNotIsInstance(arg_0, arg_0_type)
       self.assertIsInstance(arg_1, arg_1_type)
       asserts.assert_shape(arg_0, [n_copies])
+      arg_1 = _scalar_to_ndarray(arg_1, actual_shape)
       asserts.assert_shape(arg_1, [n_copies])
 
       arg_1 = np.array(arg_1)  # don't stage out operations on arg_1
@@ -812,7 +845,7 @@ class WithPmapAllAvailableDeviceTest(parameterized.TestCase):
       psum_res = jax.lax.psum(res, axis_name='j')
       return psum_res
 
-    actual = fn_static(varg_0, varg_1)
+    actual = fn_static(varg_0, arg_1)
     self.assertEqual(actual.shape, (n_devices, n_copies))
     # Exponents of `n_devices`:
     # +1: psum() inside fn()
@@ -824,7 +857,7 @@ class WithPmapAllAvailableDeviceTest(parameterized.TestCase):
     n_devices, backend = self.n_devices, self.backend
     n_copies = 5
 
-    varg_0 = jnp.zeros(n_copies) + 10
+    varg_0 = 10
     varg_1 = jnp.zeros(n_copies) + 20
     arg_0_type = type(varg_0)
     arg_1_type = type(varg_1)
@@ -838,6 +871,7 @@ class WithPmapAllAvailableDeviceTest(parameterized.TestCase):
     def fn_static(arg_0, arg_1):
       self.assertIsInstance(arg_0, arg_0_type)
       self.assertNotIsInstance(arg_1, arg_1_type)
+      arg_0 = jnp.zeros(n_copies) + arg_0
       asserts.assert_shape(arg_0, [n_copies])
       asserts.assert_shape(arg_1, [n_copies])
 
